Camelot Enhancement Proposals — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »

# Camelot Enhancement Proposals

This section contains proposals to enhance Camelot. The functionallity described here might not yet be implemented. The purpose of these documents is to discuss upcomming functions and new API’s before they are implemented.

- New Actions
  - Introduction
  - Summary
  - What can happen inside `model_run()`
    - `yield` events to the GUI
    - keep the user informed about progress
    - manipulation of the model
    - raise exceptions
    - handle exceptions
    - request information from the user
  - States and Modes
    - States
    - Modes
  - Action Context
    - Application Actions
    - Form Actions
    - List Actions
    - Reusing List and Form actions
  - Generate documents
  - Inspiration

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »

Comments
blog comments powered by Disqus